ContextMemory

Struct ContextMemory 

pub struct ContextMemory<'a> { /* private fields */ }
A type representing the memory of the emulated program.

This is used to read and write to the memory in precompile impls.

Implementations

Source

impl<'a> ContextMemory<'a>

pub const fn tracing(&self) -> bool

pub fn mr(&self, addr: u64) -> u64

Read a u64 from the memory.

pub fn mw(&mut self, addr: u64, val: u64)

Write a u64 to the memory.

pub fn mr_slice( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone

Read a slice of u64 from the memory.

pub fn mr_slice_unsafe( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone

pub fn mw_slice(&mut self, addr: u64, vals: &[u64])

Write a slice of u64 to the memory.

pub fn mr_slice_no_trace( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone

pub fn mw_hint(&mut self, addr: u64, val: u64)

Write a u64 to memory, without tracing and sets the clk in the entry to 0.