JitContext

Struct JitContext 

pub struct JitContext {
    pub pc: u64,
    pub clk: u64,
    pub global_clk: u64,
    pub is_unconstrained: u64,
    /* private fields */
}

Fields

pc: u64

The current program counter

clk: u64

The number of cycles executed.

global_clk: u64

The number of cycles executed.

is_unconstrained: u64

This context is in unconstrainted mode. 1 if unconstrained, 0 otherwise.

Implementations

Source

impl JitContext

pub unsafe fn trace_mem_access(&self, reads: &[MemValue])

Safety
  • todo
pub fn enter_unconstrained(&mut self) -> Result<()>

Enter the unconstrained context, this will create a COW memory map of the memory file descriptor.

pub fn exit_unconstrained(&mut self)

Exit the unconstrained context, this will restore the original memory map.

pub unsafe fn trace_hint(&mut self, addr: u64, value: Vec<u8>)

Indicate that the program has read a hint.

This is used to store the hints read by the program.

Safety
  • The address must be aligned to 8 bytes.
  • The hints pointer must not be mutably aliased.
pub const fn memory(&mut self) -> ContextMemory<'_>

Obtain a mutable view of the emulated memory.

pub const unsafe fn input_buffer(&mut self) -> &mut VecDeque<Vec<u8>>

Safety
  • The input buffer must be non null and valid to read from.
pub const unsafe fn public_values_stream(&mut self) -> &mut Vec<u8>

Safety
  • The public values stream must be non null and valid to read from.
pub const fn registers(&self) -> &[u64; 32]

Obtain a view of the registers.

pub const fn rw(&mut self, reg: RiscRegister, val: u64)

pub const fn rr(&self, reg: RiscRegister) -> u64

pub const fn tracing(&self) -> bool