pub struct ContextMemory<'a> { /* private fields */ }Expand description
A type representing the memory of the emulated program.
This is used to read and write to the memory in precompile impls.
Implementations
Sourceimpl<'a> ContextMemory<'a>
impl<'a> ContextMemory<'a>
pub const fn tracing(&self) -> bool
Sourcepub fn mr_slice(
&self,
addr: u64,
len: usize,
) -> impl IntoIterator<Item = &u64> + Clone
pub fn mr_slice( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone
Read a slice of u64 from the memory.
pub fn mr_slice_unsafe( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone
pub fn mr_slice_no_trace( &self, addr: u64, len: usize, ) -> impl IntoIterator<Item = &u64> + Clone